package com.nokia.dingtalkapi.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.redis.connection.lettuce.LettuceConnectionFactory;
import org.springframework.data.redis.core.RedisTemplate;

import com.nokia.dingtalkapi.properties.DingtalkRedisProperties;

/**
 * 根据配置考虑是否配置独立的redis
 * 使用lettuce框架，仅支持独立部署的redis
 */
@Configuration
@ConditionalOnBean(type = { "DingtalkProperties" })
@ConditionalOnProperty(name = "dingtalk.api.redis.enable", havingValue = "true", matchIfMissing = false)
@EnableConfigurationProperties(DingtalkRedisProperties.class)
public class DingtalkRedisAutoConfiguration {

    @Autowired
    private DingtalkRedisProperties properties;

    @Bean
    public RedisTemplate<String, Object> redisTemplate() {
        LettuceConnectionFactory factory = new LettuceConnectionFactory(properties.getHost(), properties.getPort());
        factory.setDatabase(properties.getDatabase());
        RedisTemplate<String, Object> redisTemplate = new RedisTemplate<>();
        redisTemplate.setConnectionFactory(factory);
        return redisTemplate;
    }
}
